@@ -49,7 +49,7 @@ Query::Query(QWidget* parent, const QString& _name) : ChatWindow(parent)
     QString whatsthis = i18n("<qt><p>Some details of the person you are talking to in this query is shown in this bar. The full name and hostmask is shown.</p><p>See the <i>Konversation Handbook</i> for an explanation of what the hostmask is.</p></qt>");
     queryHostmask->setWhatsThis(whatsthis);
 
-    IRCViewBox* ircViewBox = new IRCViewBox(m_headerSplitter);
+    auto* ircViewBox = new IRCViewBox(m_headerSplitter);
     m_headerSplitter->setStretchFactor(m_headerSplitter->indexOf(ircViewBox), 1);
     setTextView(ircViewBox->ircView());               // Server will be set later in setServer();
     ircViewBox->ircView()->setContextMenuOptions(IrcContextMenus::ShowNickActions, true);
@@ -57,8 +57,8 @@ Query::Query(QWidget* parent, const QString& _name) : ChatWindow(parent)
     connect(textView,&IRCView::urlsDropped,this,&Query::urlsDropped);
 
     // This box holds the input line
-    QWidget* inputBox=new QWidget(this);
-    QHBoxLayout* inputBoxLayout = new QHBoxLayout(inputBox);
+    auto* inputBox=new QWidget(this);
+    auto* inputBoxLayout = new QHBoxLayout(inputBox);
     inputBox->setObjectName(QStringLiteral("input_log_box"));
     inputBoxLayout->setSpacing(spacing());
     inputBoxLayout->setContentsMargins(0, 0, 0, 0);
@@ -89,7 +89,7 @@ Query::Query(QWidget* parent, const QString& _name) : ChatWindow(parent)
 
     updateAppearance();
 
-    #ifdef HAVE_QCA2
+    #if HAVE_QCA2
     m_cipher = nullptr;
     #endif
 }
@@ -226,11 +226,7 @@ void Query::sendText(const QString& sendLine)
     OutputFilter::replaceAliases(outputAll, this);
 
     // Send all strings, one after another
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    const QStringList outList = outputAll.split(QLatin1Char('\n'), QString::SkipEmptyParts);
-#else
     const QStringList outList = outputAll.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
-#endif
     for (const QString& output : outList) {
 
         // encoding stuff is done in Server()
@@ -276,11 +272,7 @@ void Query::textPasted(const QString& text)
 {
     if(m_server)
     {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        const QStringList multiline = text.split(QLatin1Char('\n'), QString::SkipEmptyParts);
-#else
         const QStringList multiline = text.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
-#endif
         for (QString line : multiline) {
             QString cChar(Preferences::self()->commandChar());
             // make sure that lines starting with command char get escaped
@@ -327,7 +319,7 @@ void Query::showEvent(QShowEvent*)
 
 void Query::sendFileMenu()
 {
-    emit sendFile(getName());
+    Q_EMIT sendFile(getName());
 }
 
 void Query::childAdjustFocus()
@@ -368,7 +360,7 @@ void Query::nickInfoChanged()
 
         tooltip << "<qt>";
 
-        tooltip << "<table cellspacing=\"5\" cellpadding=\"0\">";
+        tooltip << R"(<table cellspacing="5" cellpadding="0">)";
 
         m_nickInfo->tooltipTableData(tooltip);
 
@@ -376,7 +368,7 @@ void Query::nickInfoChanged()
         queryHostmask->setToolTip(strTooltip);
     }
 
-    emit updateQueryChrome(this,getName());
+    Q_EMIT updateQueryChrome(this,getName());
     emitUpdateInfo();
 }
 
@@ -448,7 +440,7 @@ void Query::emitUpdateInfo()
     else
         info = getName();
 
-    emit updateInfo(info);
+    Q_EMIT updateInfo(info);
 }
 
 // show quit message of nick if we see it
@@ -471,7 +463,7 @@ void Query::quitNick(const QString& reason, const QHash<QString, QString> &messa
     }
 }
 
-#ifdef HAVE_QCA2
+#if HAVE_QCA2
 Konversation::Cipher* Query::getCipher() const
 {
     if(!m_cipher)
